@@ -3,7 +3,7 @@
 """
 picast - a simple wireless display receiver for Raspberry Pi
 
-    Copyright (C) 2019 Hiroshi Miura
+    Copyright (C) 2019,2020 Hiroshi Miura
     Copyright (C) 2018 Hsun-Wei Cho
 
 This program is free software: you can redistribute it and/or modify
@@ -22,7 +22,8 @@ import socket
 from logging import getLogger
 
 import zeroconf
-from picast.settings import Settings
+
+from .settings import Settings
 
 
 class ServiceDiscovery():
